@@ -12,7 +12,7 @@ test_that("check_data works", {
 test_that("check_data fails", {
   expect_chk_error(
     check_data(data.frame(), nrow = TRUE),
-    "`nrow[(]`data.frame[(][)]`[)]` must be greater than 0, not 0."
+    "`nrow[(]data.frame[(][)][)]` must be greater than 0, not 0."
   )
   expect_chk_error(
     check_data(data.frame(), values = list(x = 1)),
